# Mars Buggy

This is

## Installation
Run the following to install:
```python3
pip3 install marsbuggy
```

## Usage
some sample code to show how to use it
```
```

## Developing

``` bash
pip3 install -e .[dev]
```